==> haskell-basement-0.0.8-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: basement
version: 0.0.8
id: basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3
key: basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3
license: BSD-3-Clause
copyright: 2015-2017 Vincent Hanquez <vincent@snarc.org>
           , 2017-2018 Foundation Maintainers
maintainer: vincent@snarc.org
homepage: https://github.com/haskell-foundation/foundation#readme
synopsis: Foundation scrap box of array & string
description:
    Foundation most basic primitives without any dependencies
category: Web
abi: ca5c41f50e204df2ae81595eb33f7115
exposed: True
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.CharUTF8 Basement.Types.OffsetSize
    Basement.Types.Ptr Basement.Types.Word128 Basement.Types.Word256
    Basement.UArray Basement.UArray.Mutable
hidden-modules: Basement.Error Basement.Show Basement.Runtime
                Basement.Alg.Class Basement.Alg.Mutable Basement.Alg.PrimArray
                Basement.Alg.UTF8 Basement.Alg.String Basement.Numerical.Conversion
                Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
                Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
                Basement.String.CaseMapping Basement.String.Encoding.Encoding
                Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
                Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
                Basement.Terminal.Size
import-dirs: /usr/lib/ghc-8.4.3/site-local/basement-0.0.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/basement-0.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/basement-0.0.8
hs-libraries: HSbasement-0.0.8-8QjArDsw3GWCcbHE5iqtz3
depends:
    base-4.11.1.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
haddock-interfaces: /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html: /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-basement-0.0.8-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-basement.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: basement
version: 0.0.8
id: basement-0.0.8-LdnmevtSRu4FZXxmMQJlGY
key: basement-0.0.8-LdnmevtSRu4FZXxmMQJlGY
license: BSD-3-Clause
copyright: 2015-2017 Vincent Hanquez <vincent@snarc.org>
           , 2017-2018 Foundation Maintainers
maintainer: vincent@snarc.org
homepage: https://github.com/haskell-foundation/foundation#readme
synopsis: Foundation scrap box of array & string
description:
    Foundation most basic primitives without any dependencies
category: Web
abi: e12e485ea78d66a03dfbc9737f7d1809
exposed: True
exposed-modules:
    Basement.Alg.XorShift Basement.Base16 Basement.Bindings.Memory
    Basement.Bits Basement.Block Basement.Block.Builder
    Basement.Block.Mutable Basement.BlockN Basement.Bounded
    Basement.BoxedArray Basement.Cast Basement.Compat.AMP
    Basement.Compat.Base Basement.Compat.Bifunctor
    Basement.Compat.C.Types Basement.Compat.CallStack
    Basement.Compat.ExtList Basement.Compat.Identity
    Basement.Compat.IsList Basement.Compat.MonadTrans
    Basement.Compat.Natural Basement.Compat.NumLiteral
    Basement.Compat.PrimTypes Basement.Compat.Primitive
    Basement.Compat.Semigroup Basement.Compat.Typeable
    Basement.Endianness Basement.Environment Basement.Exception
    Basement.FinalPtr Basement.Floating Basement.From Basement.Imports
    Basement.IntegralConv Basement.Monad Basement.MutableBuilder
    Basement.Nat Basement.NonEmpty Basement.NormalForm
    Basement.Numerical.Additive Basement.Numerical.Multiplicative
    Basement.Numerical.Number Basement.Numerical.Subtractive
    Basement.PrimType Basement.Sized.Block Basement.Sized.List
    Basement.Sized.UVect Basement.Sized.Vect Basement.String
    Basement.String.Builder Basement.Terminal Basement.Terminal.ANSI
    Basement.These Basement.Types.AsciiString Basement.Types.Char7
    Basement.Types.CharUTF8 Basement.Types.OffsetSize
    Basement.Types.Ptr Basement.Types.Word128 Basement.Types.Word256
    Basement.UArray Basement.UArray.Mutable
hidden-modules: Basement.Error Basement.Show Basement.Runtime
                Basement.Alg.Class Basement.Alg.Mutable Basement.Alg.PrimArray
                Basement.Alg.UTF8 Basement.Alg.String Basement.Numerical.Conversion
                Basement.Block.Base Basement.UTF8.Base Basement.UTF8.Helper
                Basement.UTF8.Table Basement.UTF8.Types Basement.UArray.Base
                Basement.String.CaseMapping Basement.String.Encoding.Encoding
                Basement.String.Encoding.UTF16 Basement.String.Encoding.UTF32
                Basement.String.Encoding.ASCII7 Basement.String.Encoding.ISO_8859_1
                Basement.Terminal.Size
import-dirs: /usr/lib/ghc-8.6.1/site-local/basement-0.0.8
library-dirs: /usr/lib/ghc-8.6.1/site-local/basement-0.0.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/basement-0.0.8
hs-libraries: HSbasement-0.0.8-LdnmevtSRu4FZXxmMQJlGY
depends:
    base-4.12.0.0 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-basement/html/basement.haddock
haddock-html: /usr/share/doc/haskell-basement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
